'''
@uthor: Max, 26th December 2018
Description: Python script that generates inputs and executes a VASP NEB calculation 
'''

#import libraries
from ase.io import read
from ase.calculators.vasp import Vasp
import os
import subprocess
from datetime import datetime

startTime = datetime.now()

#Set up parameters
atobj=read('POSCAR') #read atoms object
System=atobj.copy() #make copy of atoms object
vasp_settings = {'pp': 'PBE',             #Pseudopotential used
                 'reciprocal': False,     #Projection operators evaluated in real space if False
                 'xc': 'PBE',             #Exchange functional
                 'gga': 'PE',             #Type of GGA: Perdew-Burke-Erzenhof
                 'kpts': (3, 3, 1),       #Number of k-points
                 'setups': {'Zr': '_sv'}} #orbitals to include for Zr 

#Initalize 1st Calculation
calc = Vasp(**vasp_settings) #Create a VASP calculator object
calc.initialize(System)
calc.write_kpoints() #Generate a VASP KPOINTS file 
calc.write_potcar() #Generate a VASP POTCAR file
print('1st NEB calculation underway\n')
calc.run()
"""
#Prepare for 2nd NEB Calculation
os.system('nebp2po')#rename POSCARs to POSCAR_originals
os.system('nebc2p')#rename CONTCARs to POSCARs
calc1_runtime = ((datetime.now() - startTime).total_seconds())/3600
print('1st Calculation Runtime (hours): %.2f' % calc1_runtime)
os.system('nebrm')

#Initialize 2nd Calculation
vasp_settings['kpts']=(3, 3, 1)#Update KPOINTs
calc2 = Vasp(**vasp_settings) #Create a VASP calculator object
calc2.initialize(System)
calc2.write_kpoints() #Generate a VASP KPOINTS file 
print('2nd NEB calculation underway\n')
calc2.run()
#Print Result
print('Calculation complete \n')
total_runtime = ((datetime.now() - startTime).total_seconds())/3600
print('Total Runtime (hours): %.2f' % total_runtime)
"""